/*
 * Copyright (c) 2001 VM Labs, Inc.  All rights reserved.
 *
 * NOTICE: VM Labs permits you to use, modify, and distribute this file
 * in accordance with the terms of the VM Labs license agreement
 * accompanying it. If you have received this file from a source other
 * than VM Labs, then your use, modification, or distribution of it
 * requires the prior written permission of VM Labs.
*/

#define MAZE_MAX_W 37
#define MAZE_MAX_H 24

typedef struct {
  char widthCalib[MAZE_MAX_W+1];
  char maze[MAZE_MAX_W * MAZE_MAX_H+1];
  int h, w;
  int offsetX, offsetY;
  int distance;
} LEVEL;

typedef struct {
  int score;
  char name[9];
  int percent;
} sLevelScore;

sLevelScore *aLevelScore;

/*
   # = Wall
   . = Pill
   * = Fruit
   o = Extra Strength Pill

   % = Slow tile (empty)
   : = Slow tile (pill)
   @ = Slow tile (extra strength pill)
   $ = Slow tile (fruit)

   A-P = Specific wall tiles
    A   E   I   M
        #       #
    #   #  ##  ##


    B   F   J   N
        #       #
    #   #  ##  ##
    #   #   #   #

    C   G   K   O
        #       #
    ##  ## ### ###


    D   H   L   P
        #       #
    ##  ## ### ###
    #   #   #   #

   X = Hero start position
   1,2,3,4,5 = Enemy start positions
*/

LEVEL aLevelTournament[]=
{
  {
    "-----------------------------",

    "  #########  F:F  #########  "
    "  #o. . . ####%#### . . .o#  "
    "###.#####.#. . . .#.#####.###"
    "# . .   . . ##### . .   . . #"
    "#.#### #### #1*2# #### ####.#"
    "# # .  . .  # # # . . . . # #"
    "#.#.#.### #. .#. .# ###.#.#.#"
    "# # #  .  # # # # #  .  # # #"
    "#  .#.# #.#.#.#.#.#.# #.#.  #"
    "# # # #*# # # * # # #*# # # #"
    "#.#.#.# #.#.#####.#.# #.#.#.#"
    "# # #  .  #   X   #  .  # # #"
    "#. .#.###.#.#####.#.###.#. .#"
    "# #    .  .  . .  .  .    # #"
    "# ## ### #####%##### ### ## #"
    "#o  . . .#   #:#   #. . .  o#"
    "##########   F%F   ##########"
  },

  {
    "--------------------------------",

    "      #########  #########      "
    "   #### . . . #  # . . . ####   "
    "K### . .#####.####.#####. . ###K"
    "%%% .## # . . .  . . . # ##. %%%"
    "K### #o . ### #1 # ### . o# ###K"
    "   #.#### # . #32#  .# ####.#   "
    "   # . . . .#.####.#. . . . #   "
    "  ##### ### # .  . # ### #####  "
    "  #. . .#. .####.###. .#. . .#  "
    "  # ### # ###* .. *### # ### #  "
    "K##.#o#.#. .###.####. .#.#o#.##K"
    "%%  # . . # # .  . # # . . #  %%"
    "K##.#.#####.#.####.#.#####.#.##K"
    "  # . . . . .  X   . . . . . #  "
    "  ############################  "
  },

  {
    "-------------------------------------",

    " ###############     ############### "
    " #. . . . . . .##   ##..  ......   # "
    " # # ####### # .#   #. ## ###### #.# "
    "##.#. . . . .## #   #.##o ...#.  #.##"
    ":% # ##### #1.#.#   # #..# ###.#.#.%:"
    "##.#o . . .## # #   #  .##*2 #.#.  ##"
    " # ####.#####.#.#   #.#. ### #.#.#.# "
    " #. . . . . . . #   #.## ...     #.# "
    " # ####.###.###o#   #  ##### ### #.# "
    " #X . . . . . *##   ## ..... ...   # "
    " ###########%###     ####%########## "
    "           #:#          #:#          "
    "           #:#          #:#          "
    " ###########%###     ####%########## "
    " #* . .#.# . . ##   ##*# . #.. # . # "
    " # ###  . .###.o#   ##3#.#.###. .#.# "
    " #.###.#.# ### ##   #. . # . . # # # "
    " # . .4#.#. . . #   # ####### ##...# "
    "##.#####.######.#   #. . . . . ######"
    ":% ............ #   # ####.###.#. .%:"
    "##.#####.###### #   #.  o#.# . . # ##"
    " # #####.##*## .#   ##.###.#.#####.# "
    " #. . . . . . .##   ## ... . . . . # "
    " ###############     ############### "
  },

  {
    "--------------------",

    "   ## ######## ##   "
    "  ##. .  ..  . .##  "
    "#### ###### ### ####"
    "# . . . .2 . . . . #"
    "#.###### #########.#"
    "# #*  . .... .  *# #"
    "#.# ###### ##### #.#"
    " 1 . . . .. . . .3  "
    "#.#.## ###### ##.#.#"
    "# # ##.######.## # #"
    "# . .  . .. .  . . #"
    "#.# #####  ##### #.#"
    "# #. . .    . . .# #"
    "#.## # ###### # ##.#"
    "# . .#.  ..  .#. . #"
    "#### # #.##.# # ####"
    "%:%:.#.# ** #.#.:%:%"
    "#### # ###### # ####"
    "#. . #. . X. .# . .#"
    "# ##.# ###### #.## #"
    "#.#* . . .. . . *#.#"
    "# #######  ####### #"
    "#.4. . . .. . . .5.#"
    "##### ######## #####"
  },

  {
    "-----------------------",

    "#######################"
    "#o #       *       # o#"
    "#    ###5#####6###    #"
    "## #               # ##"
    "#    ######o######    #"
    "# ##               ## #"
    "#*#3 ### ##### ### 4#*#"
    "# #  #     *     #  # #"
    "# ##   #o# # #o#   ## #"
    "#    ##### # #####    #"
    "## #    1# X #2    # ##"
    "#    ### # # # ###    #"
    "#o #       #       # o#"
    "#######################",
  },

  {
    "-----------------------------",

    "  #########################  "
    "  # . . # . . . # . . # . #  "
    "###.#.#.#.#.#.# #.#.#.# #.###"
    "# . # . # # * # # # . #.# . #"
    "#.# * #.#.#.# . #.#.#.# . # #"
    "#.#.# # . # # #.# . # . #.#.#"
    "# # #.#.# . #.# . # #.#.# . #"
    "#.#.# . # # . X.#.#.# . #.#.#"
    "# . # #.#.#.# # # # #.#.# . #"
    "#.#.#.# * # #.#.#.#.# # * #.#"
    "# # . #.# #.# . # . # . #.# #"
    "#.#.#.# #.# . #.#.#.#.# . #.#"
    "# . # # . #.# # * # * # # . #"
    "###.#.#.#.# #.#.#.#.#.#.#.###"
    "  # . # . . . # . . # . . #  "
    "  #########################  ",
  },


  {
    "-------------------------------------",

    "    ##############:##############    "
    "    #.  o . . . .#%#. . . . o  .#    "
    "    # ## ####.## #:# ##.#### ## #    "
    "    # ## ####.## # # ##.#### ## #    "
    "    #.  . . . . . . . . . . .  .#    "
    "    # #####.#### ### ####.##### #    "
    "    #.# . # . .#.#*#.#. . # . #.#    "
    "##### #.#.#.## # # # # ##.#.#.# #####"
    "$:%: .# # .X.#.#.#.#.#.#.3. # #. :%:%"
    "##### #.#### # . # # . # ####.# #####"
    "    # . . . .###.#.#.###. . . . #    "
    "    ######## . . . . . . ########    "
    "    # . . . .###.#.#.###. . . . #    "
    "##### #.#### # . # # . # ####.# #####"
    "%:%: .# # .1.#.#.#.#.#.#.2. # #. :%:$"
    "##### #.#.#.## # # # # ##.#.#.# #####"
    "    #.# . # . .#.#*#.#. . # . #.#    "
    "    # #####.#### ### ####.##### #    "
    "    #.  . . . . . . . . . . .  .#    "
    "    # ## ####.## # # ##.#### ## #    "
    "    # ## ####.## #:# ##.#### ## #    "
    "    #.  o . . . .#%#. . . . o  .#    "
    "    ##############:##############    ",
  },

  {
    "---------------------------------",

    "#################################"
    "#* . . . . . . . . . . . . . . *#"
    "# ##############6############## #"
    "#.#o . . . . . . . . . . . . o#.#"
    "# # # ##################### # # #"
    "#.#.#:%:%:%:%:%:%:%:%:%:%:%:#.#.#"
    "# #.#%##########3##########%#.# #"
    "#.#.#:#o . . . . . . . . o#:#.#.#"
    "# #.#%# # ############# # #%#.# #"
    "#.#.#:#.#. . . . . . . .#.#:#.#.#"
    "# 4.#%2 # ######*###### # 1%#.5 #"
    "#.#.#:#.#. . . . . . . .#.#:#.#.#"
    "# #.#%# # ############# # #%#.# #"
    "#.#.#:#o . . . . . . . . o#:#.#.#"
    "# #.#%##########X##########%#.# #"
    "#.#.#:%:%:%:%:%:%:%:%:%:%:%:#.#.#"
    "# # # ##################### # # #"
    "#.#o . . . . . . . . . . . . o#.#"
    "# ##############.############## #"
    "#* . . . . . . . . . . . . . . *#"
    "#################################"
  },
  
  {
    "-------------------------------------",
    "##### # ###.## #.###.#.#### #### ####"
    "#. 2# . # . .# # #.# # . .#. . . . .#"
    "###.#####.#### #.# # ###.#####.######"
    ". # . . . . . .# #. . .  # . . . . . "
    "#.#.## ####### #.# ### #.#.#.###.####"
    "# . .#.#.  *#. . #.#*#.# # ###.### o#"
    "# #### # #######.  # # #. . .   . . #"
    "#.#o #. .#.#.# . ### #.##.###.###.###"
    ". # .  # . . #.#.#. .# #. #.# . . # ."
    "#.#.##.####### # # ###.####3#####.# #"
    "# . #. .# . . .#. .# . . .#. .  . #.#"
    "#########.#### ### #.##########.### #"
    "  .#. . . o .# #X. . .#. . .  . . . ."
    "#.###.########.# ###### #####.#######"
    "# . .  . .#.1###. . . #.# . . #. . .#"
    "###.########.# . ####.###.##### # ###"
    "#.  .  . * # #.###. . . . #. . .#. .#"
    "# ###### #.# o #.# ######## ###4# # #"
    ". # . . .#  .# # #.# . . .#. *#.#.#. "
    "###.#.########.#.# #.#### ##### #####"
    ". . # . .  . . # . . #.#o . #. .#. . "
    "#.###.###.##.###.#.### ####.# ### ###"
    "# . . # . #. #*# # . # . .# #. . . .#"
    "#####.#.### ## # ###.#.####.#### ####"
  },

  {
    "-----------------------",
    "#######################"
    "#..........#..........#"
    "#oDKJ.DKKJ.#.DKKJ.DKJo#"
    "#.GKM.GKKM.#.GKKM.GKM.#"
    "#.....................#"
    "#.###.#.#######.#.###.#"
    "#.....#....#....#.....#"
    "#####.####.#.####.#####"
    "    #.#         #.#    "
    "K####.# ### ### #.####K"
    "%%%%%.  #12345# #.%%%%%"
    "K####.# ####### #.####K"
    "    #.#    *    #.#    "
    "#####.# ####### #.#####"
    "#..........#..........#"
    "#.###.####.#.####.###.#"
    "#o..#......X......#..o#"
    "###.#.#.#######.#.#.###"
    "#.....#....#....#.....#"
    "#.########.#.########.#"
    "#.....................#"
    "#######################"
  },
  
  {
    ""
  }
};

LEVEL levels[]=
{
  {
    "-------------------------------------",

    "  #############       #############  "
    "  # .  .  .   #       #   .  .  . #  "
    "### # ## ####.#########.#### ## # ###"
    "# . # .#.#*#  .  . .  .  #*#.#. # . #"
    "# #### # # ## ######### ## # # #### #"
    "#.  .  .  .  .  . o .  .  .  .  .  .#"
    "### # ######## ####### ######## # ###"
    "  #.# .  .  .  .  .  .  .  .  . #.#  "
    "  # #  #### ##### # ##### ####  # #  "
    "  #. . .#  .  .  .#.  .  .  #. . .#  "
    "  # # #  . #.#### # ####.# .  # # #  "
    "  #.#.#.#### #. .   . .# ####.#.#.#  "
    "  #   # # . .# ### ### #. . # #   #  "
    "  #.#.#.# ####.# 1 2 #.#### #.#.#.#  "
    "### # # # .  . ####### .  . # # # ###"
    "#  . . .# #### . . . . #### #. . .  #"
    "#.# # # .  . ########### .  . # # #.#"
    "# # #*### #  . #  .  # .  # ###*# # #"
    "#.# # . # # #  . # # .  # # # . # #.#"
    "# # ### # # ###### ###### # # ### # #"
    "#.# o  .  .  .  . X .  .  .  .  o #.#"
    "# ###### ######### ######### ###### #"
    "# .  .  .  .  .  . .  .  .  .  .  . #"
    "#####################################"
  },

  {
    "-------------------------------------",

    "  #############       #############  "
    "  # .  .  .   #       #   .  .  . #  "
    "### # ## ####.#########.#### ## # ###"
    "# . # .#.#*#  .  .2.  .  #*#.#. # . #"
    "# #### # # ## ######### ## # # #### #"
    "#.  .  .  .  .  . o .  .  .  .  .  .#"
    "### # ######## ####### ######## # ###"
    "  #.# .  .  .  .  .  .  .  .  . #.#  "
    "  # #  #### ##### # ##### ####  # #  "
    "  #. . .#  .  .  .#.  .  .  #. . .#  "
    "  # # #  . #.#### # ####.# .  # # #  "
    "  #.#.#.#### #. .   . .# ####.#.#.#  "
    "  #   # # . .# ### ### #. . # #   #  "
    "  #.#.#.# ####.# 1 3 #.#### #.#.#.#  "
    "### # # # .  . ####### .  . # # # ###"
    "#  . . .# #### . . . . #### #. . .  #"
    "#.# # # .  . ########### .  . # # #.#"
    "# # #*### #  . #  .  # .  # ###*# # #"
    "#.# # . # # #  . # # .  # # # . # #.#"
    "# # ### # # ###### ###### # # ### # #"
    "#.# o  .  .  .  . X .  .  .  .  o #.#"
    "# ###### ######### ######### ###### #"
    "# .  .  .  .  .  . .  .  .  .  .  . #"
    "#####################################"
  },

	{
    "-------------------------------------",

            "  #############       #############  "
			"  # .  .  .   #       #   .  .  . #  "
			"### # ## ####.#########.#### ## # ###"
			"# . # .#.#*#  .  . .  .  #*#.#. # . #"
			"# #### # # ## ######### ## # # #### #"
			"#.  .  .  .  .  . o .  .  .  .  .  .#"
			"### # ######## ####### ######## # ###"
			"  #.# .  .  .  .  .  .  .  .  . #.#  "
			"  # #  #### ##### # ##### ####  # #  "
			"  #. . .#  .  .  .#.  .  .  #. . .#  "
			"  # # #  . #.#### # ####.# .  # # #  "
			"  #.#.#.#### #. .   . .# ####.#.#.#  "
			"  #   # # . .# ### ### #. . # #   #  "
			"  #.#.#.# ####.# 1 2 #.#### #.#.#.#  "
			"### # # # .  . ####### .  . # # # ###"
			"#  . . .# #### . . . . #### #. . .  #"
			"#.#3# # .  . ########### .  . # #4#.#"
			"# # #*### #  . #  .  # .  # ###*# # #"
			"#.# # . # # #  . # # .  # # # . # #.#"
			"# # ### # # ###### ###### # # ### # #"
			"#.# o  .  .  .  . X .  .  .  .  o #.#"
			"# ###### ######### ######### ###### #"
			"# .  .  .  .  .  . .  .  .  .  .  . #"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"# .  .  .  .# .  .*.  . #.  .  .  . #"
			"# #### #### # ######### # #### #### #"
			"#.# .  .  # . #  . .  # . #  .  . #.#"
			"#   ##### # # . # o # . # # #####   #"
			"#.# # .  .  #  ###.###  #  .  . # #.#"
			"# # # ##### #### . . #### ##### # # #"
			"#.# .  .  . #  . # # .  # .  .  . #.#"
			"# # # # # # # #### #### # # # # # # #"
			"#.#*#o# #.#   # 12345 #   #.# #o#*#.#"
			"# # # #.# # # #### #### # # #.# # # #"
			"#.  #.# #.# #.  .   .  .# #.# #.#  .#"
			"# ### # # # # ######### # # # # ### #"
			"#.# .  .  . # .  . .  . # .  .  . #.#"
			"# # ####### # ######### # ####### # #"
			"#.# . # . # .  .  .  .  . # . # . #.#"
			"#   # . # . ############# . # . #   #"
			"# ########   . .  X  . .   ######## #"
			"#.  .   .#.###############.#.   .  .#"
			"# ###### #  .  ##   ##  .  # ###### #"
			"#.  .  #.#.# # .  #  . # #.#.#  .  .#"
			"# #### # # # ########### # # # #### #"
			"#.  .   .  #   .  *  .   #  .   .  .#"
			"#####################################"
	},
	{
    "-------------------------------------",

            
            "#####################################"
			"#. . . . . . . . . . . . . . . . . .#"
			"# ###### ######## # ######## ###### #"
			"#  . . . . . . .  # . . . .   . . . #"
			"#o######.########.#.########.######o#"
			"#  . . . . . . . . . . . . . . . .  #"
			"#.######.#.###############.#.######.#"
			"#  . . . #. . . . #. . . . # . . .  #"
			"########.######## # ########.########"
			"       # #                 # #       "
			"########.#   ##### #####   #.########"
			"#            #         #            #"
			"#       .    #  12345  #    .       #"
			"######## #   ##### #####   # ########"
			"       #.#        *        #.#       "
			"######## # ############### # ########"
			"#. . . . . . . . .#. . . . . . . . .#"
			"# ######.########.#.########.###### #"
			"#o. . .#  . . . . X . . . .  #. . .o#"
			"###### #.#.###############.#.# ######"
			"#. . . . # . . . .#. . . . # . . . .#"
			"# ###############.#.############### #"
			"#. . . . . . . . . . . . . . . . . .#"
			"#####################################"
	},
	{
    "-------------------------------------",

            
            "#####################################"
			"#o . . .#. . . . . . . . . .#. . . o#"
			"# ##### # ################# # ##### #"
			"#. . . . . . . . . . . . . . . . . .#"
			"##### # #########   ######### # #####"
			"#. . .#. . . . . .#. . . . . .#. . .#"
			"##### # ######### # ######### # #####"
			"    #.#. . . . . .#. . . . . .#.#    "
			"    # #### # ########### # #### #    "
			"    #. . . . . . . . . . . . . .#    "
			"    # #### # ####   #### # #### #    "
			"    #.# . .# #         #.#. . #.#    "
			"    #.#.# .#.#  12345  #.#. #.#.#    "
			"##### # # ## ##### ##### ## # # #####"
			"#. . . .#. . . . .*. . . . .#. . . .#"
			"##### ########### # ########### #####"
			"    #. . . . . . .#. . . . . . .#    "
			"##### ###### ########### ###### #####"
			"#. . . . . . . . .X. . . . . . . . .#"
			"# ###### ######## # ######## ###### #"
			"#o#    #.#. . . . # . . . .#.#    #o#"
			"# ###### # ############### # ###### #"
			"#. . . . . . . . . . . . . . . . . .#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#. . . . . . .#. .#. .#. . . . . . .#"
			"# ######### # # # # # # # ######### #"
			"#o#       #.#.#.#.#.#.#.#.#       #o#"
			"# ######### #   #   #   # ######### #"
			"#. . . . .#. . . . . . . .#. . . . .#"
			"# ####### ################# ####### #"
			"#. . . . . . . . . . . . . . . . . .#"
			"# ########### #### #### ########### #"
			"# . . . . . # #       # # . . . . . #"
			"#.#########.#.# 12345 #.#.#########.#"
			"# ####*#### # #### #### # ####*#### #"
			"#.#. . . . .#. . . . . .#. . . . .#.#"
			"# # ######### ######### ######### # #"
			"#. . . .#. . . . . . . . . .#. . . .#"
			"####### ########## ########## #######"
			"#. . . . . . . . .X. . . . . . . . .#"
			"# ##### ######### # ######### ##### #"
			"#. . .#. . . . . .#. . . . .#.#. . .#"
			"# ### # # # ############# # # # ### #"
			"#.# o #.#.#. . . .*. . . .#.#.# o #.#"
			"# # ### # ################# # ### # #"
			"#. . . . . . . . . . . . . . . . . .#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.####.#.#.#.###########.#.#.#.####.#"
			"#.#....#.#.#.#....#....#.#.#.#....#.#"
			"#.#.####.#.#.#.##...##.#.#.#.####.#.#"
			"#........#.#....#.#.#....#.#........#"
			"#.####.###.###############.###.####.#"
			"#.#......#.................#......#.#"
			"#.####.###.#######.#######.###.####.#"
			"#...................................#"
			"#.#.#.#.#.#.#.#### ####.#.#.#.#.#####"
			"#...#...#.#.#.#       #.#.#.#...#...#"
			"#.#...#...#.#.# 12345 #.#.#...#...#.#"
			"###########.#.#### ####.#.#########.#"
			"#.................*.................#"
			"#.####.###.#######.#######.###.####.#"
			"#.#......#........X........#......#.#"
			"#.####.###.###############.###.####.#"
			"#........#.#....#.#.#....#.#........#"
			"#.#.####.#.#.#.##...##.#.#.#.####.#.#"
			"#.#....#.#.#.#....#....#.#.#.#....#.#"
			"#.####.#.#.#.###########.#.#.#.####.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.....#.....................#.....o#"
			"#.####.#.#.#.###########.#.#.#.####.#"
			"#.#....#.#.#.#.........#.#.#.#....#.#"
			"#.#.####.#.#.#.##.#.##.#.#.#.####.#.#"
			"#...................................#"
			"#.####.###.##.####.####.##.###.####.#"
			"#.#......#..#...........#..#......#.#"
			"#.####.###.##.#.##.##.#.##.###.####.#"
			"#...........#.#.......#.#...........#"
			"#.#########.#.#### ####.#.######### #"
			"#.....#####.#.         .#.#####.....#"
			"#.#.......#.#.# 12345 #.#.#.......#.#"
			"#.####.####.#.#########.#.####.####.#"
			"#...........#.#...*...#.#...........#"
			"#.####.###.## #.#####.# ##.###.####.#"
			"#...........#.#...X...#.#...........#"
			"#.####.###.##.####.####.##.###.####.#"
			"#...................................#"
			"#.#.####.#.#.#.##.#.##.#.#.#.####.#.#"
			"#.#....#.#.#.#.........#.#.#.#....#.#"
			"#.####.#.#.#.###########.#.#.#.####.#"
			"#o.....#.....................#.....o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.####.#.#.#.#####.#####.#.#.#.####.#"
			"#..#...#.#.#.#.........#.#.#.#...#..#"
			"#...##.#.#.#.#####.#####.#.#.#.##...#"
			"###..#.........................#..###"
			"#.....####.#######.#######.####.....#"
			"###....#.....#...........#...#....###"
			"######.###.#######.#######.###.######"
			"#........#.................#........#"
			"#.###########.#### ####.###########.#"
			"#.............#       #.............#"
			"#.############# 12345 #############.#"
			"#.........#...#### ####...#.........#"
			"#######.##..#.....*........##.#######"
			"#.......#..##.####.####.##..#.......#"
			"#.######..........X..........######.#"
			"#.....####.##.####.####.##.####.....#"
			"###.##.........................##.###"
			"#...##.#.#.#.#.#######.#.#.#.#.##...#"
			"#..#...#.#.#.#.........#.#.#.#...#..#"
			"#.####.#.#.#.#####.#####.#.#.#.####.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.####.#.###.#####.#####.###.#.####.#"
			"#..###.#.#.#.............#.#.#.###..#"
			"#...##.#.#.#.#####.#####.#.#.#.##...#"
			"#.#...............................#.#"
			"#.########.#######.#######.########.#"
			"#...................................#"
			"#.#####.###.###### ######.###.#####.#"
			"#...#...#...#...........#...#...#...#"
			"#.#...#...#...#### ####...#...#...#.#"
			"#.#############       #############.#"
			"#.............# 12345 #.............#"
			"###########.#.#### ####.#.###########"
			"#...........#.....*.....#...........#"
			"#.###########.#########.###########.#"
			"#...........#.....X.....#...........#"
			"###########.#.####.####.#.###########"
			"#...........#...........#...........#"
			"#.###########.#########.###########.#"
			"#...........#...........#...........#"
			"###########.#.####.####.#.###########"
			"#o..........#...........#..........o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o..........#...........#..........o#"
			"#.###.#.###.#.#########.#.###.#.###.#"
			"#.....#.......................#.....#"
			"###.###.##### ######### #####.###.###"
			"#...........#...........#...........#"
			"#.###.#.###.#.#########.#.###.#.###.#"
			"#.....#.......................#.....#"
			"###.###.##### ######### #####.###.###"
			"###......####...........####......###"
			"#...###.......#### ####.......###...#"
			"###.###.#####.#       #.#####.###.###"
			"#...........#.# 12345 #.#...........#"
			"#.###.#.###.#.#### ####.#.###.#.###.#"
			"#.....#...........*...........#.....#"
			"###.###.#####.#########.##### ### ###"
			"#...........#.....X.....#...........#"
			"#.###.#.###.#.#########.#.### # ### #"
			"#.....#.......................#.....#"
			"###.###.#####.#########.#####.###.###"
			"#...........#...........#...........#"
			"#.###.#.###.#.#########.#.###.#.###.#"
			"#o....#.......................#....o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o..........#.................#....o#"
			"#.#####.###.#.##.############.#.###.#"
			"#.....#.......................#.....#"
			"###.###.##### ######.## #####.###.###"
			"#...........#...........#...........#"
			"#.###.#.###.###########.#####.#####.#"
			"#.....#.......................#.....#"
			"###.###.##### ####.#### #####.###.###"
			"###.#...#####...........####......###"
			"#...###.##....#### ####.#.....#.#...#"
			"#.#####.#####.#       #.#####.#.#.###"
			"#...........#.# 12345 #.............#"
			"#.###.#.###.#.#### ####.#.###.#.###.#"
			"#.....#.....#.....*.....#.....#.....#"
			"###.###.##.##.###############.#######"
			"#.....#.#...#.....X.....#...........#"
			"#.###.#.###.#.##.######.#.###.#.###.#"
			"#.....#...............#.....#.#.....#"
			"###.###.#####.####.####.#####.###.###"
			"#...........#...........#.......#...#"
			"#.###.#.###.#.#######.#.#.###.#.###.#"
			"#o....#.....#.........#.......#....o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o......................#.....#...#o#"
			"#.#####.#.#.##..#.#.#.#.#.###.#.#.#.#"
			"#.......#.#..##.#...#.#.#.#...#.#.#.#"
			"#.#####.#.##..#.#####.#.#.#.###.#.#.#"
			"#.....................#.#.#.#...#.#.#"
			"#.###.#.###.#########.#.#.#.#.###.#.#"
			"#.....#...............#...#...#...#.#"
			"#.#.###.#####.#######.#############.#"
			"#...................................#"
			"###.#.#.#.....#### ####.#.....#.#.###"
			"###.#.#.#####.#       #.#####.#.#.###"
			"#...........#.# 12345 #.#...........#"
			"#####.#.###.#.#### ####.#.###.#.#####"
			"#.................*.................#"
			"#.#####.#####.#########.#####.#####.#"
			"#.................X.................#"
			"#####.#..##.#.#########.#.##..#.#####"
			"#...#..#.....................#..#...#"
			"#.#..#.#.####.####.####.####.#.#..#.#"
			"#..#.#.#....#...........#....#.#.#..#"
			"##.#.#.#.##.#.#########.#.##.#.#.#.##"
			"#o.#...#.....................#...#.o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.##.#.#######################.#.##.#"
			"#....#.#..........#..........#.#....#"
			"####.#...###.#.##.#.##.#.###...#.####"
			"#....#.#.....#.........#.....#.#....#"
			"#.##.#.#######################.#.##.#"
			"#....#.........................#....#"
			"#.####.######.#########.######.####.#"
			"#...................................#"
			"#.###########.#### ####.###########.#"
			"#.#......#....#       #....#......#.#"
			"#...##.#...##.# 12345 #.##...#.##...#"
			"######.######.#### ####.######.######"
			"#.................*.................#"
			"#.####.######.#########.######.####.#"
			"#....#............X............#....#"
			"#.##.#.#######################.#.##.#"
			"#....#.#.....#.........#.....#.#....#"
			"####.#...###.#.##.#.##.#.###...#.####"
			"#....#.#..........#..........#.#....#"
			"#.##.#.#######################.#.##.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.##########.#####.#####.##########.#"
			"#.#..............#.#.....#.#..#...#.#"
			"#.#.####.###.#####.###.###....###.#.#"
			"#.#.#..............#....#..#......#.#"
			"#.#.####.#....####.####.#.##.######.#"
			"#........#.##....#.#.......#........#"
			"#.################.#####.##########.#"
			"#...................................#"
			"##.###.######.#### ####.######.###.##"
			"#....#.##.#...#       #.#.##...#....#"
			"#.##.#......#.# 12345 #......#.#.##.#"
			"####.#.######.#### ####.######.#.####"
			"#.................*.................#"
			"#.################.#####.##########.#"
			"#........#.##....#X#.......#........#"
			"#.#.####.#....####.####.#.##.######.#"
			"#.#.#..............#....#..#......#.#"
			"#.#.####.###.#####.###.###....###.#.#"
			"#.#..............#.#.....#.#..#...#.#"
			"#.##########.#####.#####.##########.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#...........###.......###...........#"
			"#o#########.###.#####.###.#########o#"
			"#.##............#####............##.#"
			"#.##.##.#######.#####.#######.##.##.#"
			"#....##.#######.#####.#######.##....#"
			"####.##.#######.#####.#######.##.####"
			"####.##.......................##.####"
			"#....######## ######### ########....#"
			"#.##                             ##.#"
			"#.######## ## #### #### ## ########.#"
			"#.         ## #       # ##         .#"
			"#.## ######## # 12345 # ######## ##.#"
			"#.## ######## #### #### ######## ##.#"
			"#.##              *              ##.#"
			"#.######## #### ##### #### ########.#"
			"#..........##...#####...##..........#"
			"######.###.##.#########.##.###.######"
			"#o.....###........X........###.....o#"
			"#.########.#####.###.#####.########.#"
			"#..........##....###....##..........#"
			"#.########.##.#########.##.########.#"
			"#..........##...........##..........#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#...................................#"
			"#o###.#######.#########.#######.###o#"
			"#.###.#######.#.......#.#######.###.#"
			"#.###.........#.#####.#.........###.#"
			"#.######.####.#.#####.#.####.######.#"
			"#........####...#####...####........#"
			"#####.######### ##### #########.#####"
			"#####.######### ##### #########.#####"
			"###......####           ####......###"
			"#...####.#### #### #### ####.####...#"
			"########.#### #       # ####.########"
			"########.     # 12345 #     .########"
			"#...####.#### #### #### ####.####...#"
			"###......####     *     ####......###"
			"###.####.###### ##### ######.####.###"
			"###.####........#####........####.###"
			"###.#########.#.#####.#.#########.###"
			"#.............#...X...#.............#"
			"#.########.##.#########.##.########.#"
			"#.###......##...........##......###.#"
			"#o###.##########.###.##########.###o#"
			"#................###................#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"##o..#########1### ###5#########..o##"
			"##.#......####.#######.####......#.##"
			"##.#.####.####..##*##..####.####.#.##"
			"##.#......####2...3...4####......#.##"
			"##...####.########.########.####...##"
			"##.#......########.########......#.##"
			"##.#.####.#######...#######.####.#.##"
			"##.#......####o##...##o####......#.##"
			"##.#.####.####.###.###.####.####.#.##"
			"##........####.........####........##"
			"##.#.####.######## ########.####.#.##"
			"##.#......####..o# #o..####......#.##"
			"##.#.#.##.####.### ###.####.##.#.#.##"
			"##.#.#.##.####..## ##..####.##.#.#.##"
			"##...........##.## ##.##...........##"
			"##.#########....## ##....#########.##"
			"##.##############...##############.##"
			"#............####...####............#"
			"#.#.########.####...####.########.#.#"
			"#.#.#o....##.............##....o#.#.#"
			"#.#.#####.#####.......#####.#####.#.#"
			"#o#.......#####...X...#####.......#o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o.................................o#"
			"#.##########.###########.##########.#"
			"#.#...............................#.#"
			"#.#.#.#########.#####.#########.#.#.#"
			"#.#.#.#...........X...........#.#.#.#"
			"#.#.#.#.########## ##########.#.#.#.#"
			"#.#.#.#.#        # #        #.#.#.#.#"
			"#...#.#.#        # #        #.#.#...#"
			"#.#.#.#.#        # #        #.#.#.#.#"
			"#.#.#.#.#      ### ###      #.#.#.#.#"
			"#.#.#.#.#      #1 3 5#      #.#.#.#.#"
			"#.#.#.#.#      # 2 4 #      #.#.#.#.#"
			"#.#.#.#.#      #######      #.#.#.#.#"
			"#.#.#.#.#                   #.#.#.#.#"
			"#.#.#.#.#                   #.#.#.#.#"
			"#...#.#.#                   #.#.#...#"
			"#.#.#.#.#####################.#.#.#.#"
			"#.#.#.#...........*...........#.#.#.#"
			"#.#.#.#########.#####.#########.#.#.#"
			"#.#...............................#.#"
			"#.##########.###########.##########.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#1....#...#......#.#......#...#....2#"
			"#.#.#...#...#.##.#*#.##.#...#...#.#.#"
			"#.#.#.##########.#.#.##########.#.#.#"
			"#.#.#*......#....#.#....#......*#.#.#"
			"#.#.#######.####.#.#.####.#######.#.#"
			"#.#...#...#.#o.........o#.#...#...#.#"
			"#.#.#.#.#.#.####.#.#.####.#.#.#.#.#.#"
			"#.#.#...#........#.#........#...#.#.#"
			"#.#.############.#.#.############.#.#"
			"#.#...........o#.#.#.#o...........#.#"
			"#.##############..X..##############.#"
			"#.........*....#######....*.........#"
			"######.#######...#5#...#######.######"
			"#o...#.#o....#.#.....#.#....o#.#...o#"
			"####.#.#####.#####.#####.#####.#.####"
			"#....#.....#.....#.#.....#.....#....#"
			"#.########.###.#.#.#.#.###.########.#"
			"#..........#.#.#.#.#.#.#.#..........#"
			"##########...#....*....#...##########"
			"#..........#...#.#.#.#...#..........#"
			"#.################.################.#"
			"#3.......*.................*.......4#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#*................o................*#"
			"#.#.#############################.#.#"
			"#.#...............................#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.............o.............#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.#   1  2  3   4    5    #.#.#.#"
			"#.#.#.#                       #.#.#.#"
			"#.#.#.###### ##### ##### ######.#.#.#"
			"#.#.#...........................#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.############X############.#.#.#"
			"#.#...............................#.#"
			"#.#.#############################.#.#"
			"#.................o.................#"
			"#.#################################.#"
			"#.#..#..#..#..#..#..#..#..#..#..#...#"
			"#...##.##.##.##.##.##.##.##.##.##..##"
			"#*................o................*#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#......o......#.........#.....o.....#"
			"#.###########.#.#######.#.#########.#"
			"#......#......#....#....#.....#.....#"
			"#.####.#.####.#.##.#.##.#.###.#.###.#"
			"#......#......#....#....#.....#.....#"
			"#.####.#.####.#.##.#.##.#.###.#.###.#"
			"#.####.............*............###.#"
			"#.#####.#.#..#############..#.#.###.#"
			"#.#######.#..#  12   34  #..#.#####.#"
			"#.#######*#..#     5     #..#*#####.#"
			"#.#######.#..#           #..#.#####.#"
			"#.#####.#.#..### ##### ###..#.#.###.#"
			"#.####.............*............###.#"
			"#.####.#.####.#.##.#.##.#.###.#.###.#"
			"#......#......#....#....#.....#.....#"
			"#.####.#.####.#.##.#.##.#.###.#.###.#"
			"#......#......#....#....#.....#.....#"
			"#.###########.#.#######.#.###.#.###.#"
			"#.............#....X....#.....#.....#"
			"#.#################.###############.#"
			"#.#################.###############.#"
			"#......o......................o.....#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o..........#...........#..........o#"
			"#.####.####.#.####.####.#.####.####.#"
			"#.####.####.#.####.####.#.####.####.#"
			"#...................................#"
			"#.####.####.#.#########.#.####.####.#"
			"#.####.####.#.#########.#.####.####.#"
			"#...........#.....#.....#...........#"
			"#.######.##.#####.#.#####.##.######.#"
			"#.######.##.#...........#.##.######.#"
			"#.....##.##.#.#### ####.#.##.##.....#"
			"#####.........#       #.........#####"
			"#####.##.##.#.# 12345 #.#.##.##.#####"
			"#.....##.##.#.#### ####.#.##.##.....#"
			"#.######.##.#.....*.....#.##.######.#"
			"#.######.##.#####.#.#####.##.######.#"
			"#...........#.....x.....#...........#"
			"#.####.####.#.#########.#.####.####.#"
			"#.####.####.#.#########.#.####.####.#"
			"#...................................#"
			"#.####.####.#.####.####.#.####.####.#"
			"#.####.####.#.####.####.#.####.####.#"
			"#o..........#...........#..........o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#...................................#"
			"#.################*################.#"
			"#..##############...##############..#"
			"#....##########.......##########....#"
			"#......######...........######......#"
			"#........##...............##........#"
			"#.o...............................o.#"
			"##################.##################"
			"#                #.#                #"
			"################ #.# ################"
			"#*.................................*#"
			"#...................................#"
			"################ #.# ################"
			"#                #.#                #"
			"##################.##################"
			"#.o...............................o.#"
			"#........##...............##........#"
			"#......######...........######......#"
			"#....##########.......##########....#"
			"#..##############...##############..#"
			"#.################*################.#"
			"#.................X.................#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#.........o##........##o............#"
			"#.###########.######.##############.#"
			"#.............######................#"
			"#.###########.#..*.#.##############.#"
			"#.#*..........#....#.............*#.#"
			"#.###########.#....#.##############.#"
			"#.............##..##................#"
			"#..##########.##..##.##############.#"
			"#..##########.......................#"
			"#..##..##..##.## ###.##..##..##..##.#"
			"#..##..##..##.# 12 #.##..##..##..##.#"
			"#..##..##..##.# 34 #.##..##..##..##.#"
			"#..##..##..##.### ##.##..##..##..##.#"
			"#....................##############.#"
			"#.###########.##..##.##############.#"
			"#.............##..##................#"
			"#.###########.#....#.##############.#"
			"#.#*..........#....#.............*#.#"
			"#.###########.#.*..#.##############.#"
			"#.............######................#"
			"#.###########.######.##############.#"
			"#.........o##...X....##o............#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o..........#...........#..........o#"
			"#.####.####.#.####.####.#.####.####.#"
			"#.###...###.#.####.####.#.###...###.#"
			"#.#...#...#...#.......#...#...#...#.#"
			"#.#.#...###.#.####.####.#.###...#.#.#"
			"#.#.##.####.#.####.####.#.####.##.#.#"
			"#...................................#"
			"#.######.########.#.########.######.#"
			"#...####....#...........#....####...#"
			"###...##.##.#.#### ####.#.##.##...###"
			"#####.........#       #.........#####"
			"#####.##.##.#.# 12345 #.#.##.##.#####"
			"###...##.##.#.#### ####.#.##.##...###"
			"#...####....#.....*.....#....####...#"
			"#.######.########.#.########.######.#"
			"#.................x.................#"
			"#.#.##.####.#.####.####.#.####.##.#.#"
			"#.#.#...###.#.####.####.#.###...#.#.#"
			"#.#...#...#...#.......#...#...#...#.#"
			"#.###...###.#.####.####.#.###...###.#"
			"#.####.####.#.####.####.#.####.####.#"
			"#o..........#...........#..........o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#.........###...........###.........#"
			"#########.###.#########.###.#########"
			"#o..............#####..............o#"
			"#.###########.#.#####.#.###########.#"
			"#.##..........#.#####.#..........##.#"
			"#.##.########.#.#####.#.########.##.#"
			"#.##.########.#.......#.########.##.#"
			"#.........###.#########.###.........#"
			"#########.###...........###.#########"
			"#########.###.#### ####.###.#########"
			"#.........###.#       #.###.........#"
			"#.#######.....# 12345 #.....#######.#"
			"#.#######.###.#### ####.###.#######.#"
			"#....####.###.....*.....###.####....#"
			"####.####.#####.#####.#####.####.####"
			"####............#####............####"
			"####.##########.#####.##########.####"
			"#........###......X......###........#"
			"####.###.###.###########.###.###.####"
			"#o...###.........###.........###...o#"
			"#.######.#######.###.#######.######.#"
			"#...................................#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#o......##.................##......o#"
			"#.#####.##.###############.##.#####.#"
			"#.#####.##.###############.##.#####.#"
			"#...................................#"
			"####.##.########.###.########.##.####"
			"####.##.########.###.########.##.####"
			"####.##..........###..........##.####"
			"#....#####.###############.#####....#"
			"####.............................####"
			"####.########.#### ####.########.####"
			"####.####.....#       #.....####.####"
			"####.####.###.# 12345 #.###.####.####"
			"####.####.###.#### ####.###.####.####"
			"#.........###.....*.....###.........#"
			"####.###########.###.###########.####"
			"####.............###.............####"
			"####.#######.###########.#######.####"
			"#.................X.................#"
			"#.#####.########.###.########.#####.#"
			"#.#####.##.......###.......##.#####.#"
			"#.#####.##.###############.##.#####.#"
			"#o.................................o#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#. . . . . . . . o . . . . . . . . .#"
			"#.#################################.#"
			"#.#. . . . . . . . . . . . . . . .#.#"
			"#.#.#############################.#.#"
			"#.#.#. . . . . . o . . . . . . .#.#.#"
			"#.#.#.#########################.#.#.#"
			"#.#.#.#. . . . . . . . . . . .#.#.#.#"
			"#.#.#.#.#####################.#.#.#.#"
			"#. . . . . . . . . . . . . . . . . .#"
			"#.#####. . . . . . . . . . . .#####.#"
			"#.#####.####. .### ###. .####.#####.#"
			"#.#####.####. .#12345#. .####.#####.#"
			"#.#####.####. .### ###. .####.#####.#"
			"#.#####. . . . . . . . . . . .#####.#"
			"#. . . . . . . . .X. . . . . . . . .#"
			"#.#.#.#########################.#.#.#"
			"#.#.#. . . . . . .o. . . . . . .#.#.#"
			"#.#.#############################.#.#"
			"#.#. . . . . . . . . . . . . . . .#.#"
			"#.#################################.#"
			"#. . . . . . . . . . . . . . . . . .#"
			"#####*#####.##### o #####.#####*#####"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#. . .o. .#. . . . . . . .#. .o. . .#"
			"#.#######.#. . . . . . . .#.#######.#"
			"#.#######.#. . . . . . . .#.#######.#"
			"#. . . . . . ########### . . . . . .#"
			"#.###. . . . .#########. . . . .###.#"
			"#.# #. . . . . .#####. . . . . .# #.#"
			"#.# #. . . . . . .#. . . . . . .# #.#"
			"#.###. . . . . . . . . . . . . .###.#"
			"#. . . . . . .####  #### . . . . . .#"
			"#. . . ##### .# 12   34# . ##### . .#"
			"#. . * # . . .#    5   # . . . # * .#"
			"#. . . . . # .####  #### . # . . . .#"
			"#.###. . . # . . . . . . . # . . ##.#"
			"#.## . ##. # ##. ##. ##. ### . ##. .#"
			"#.## . ##. ####. ##. ##. ### . ##. .#"
			"#.## . . . . . . . . . . . . . . ##.#"
			"#. . . . . . . . .#. . . . . . . . .#"
			"#.###. . . . . .#####. . . . . .###.#"
			"#.# #. . . . .#########. . . . .# #.#"
			"#.# #. . . .#############. . . .# #.#"
			"#.###. . # . . . .X. . . . # . .###.#"
			"#. o . . ######. . . .###### . . o .#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#. . . . . . . . . . . . . . . . . .#"
			"#.#################################.#"
			"#.#. . . .#. . . . . . . .#  1   5#.#"
			"#.#. o . # . . . . . . . . #   2  #.#"
			"#.#. . .#. . . ######. . . .#   3 #.#"
			"#.#. . . . . . # o .#. . . .     4#.#"
			"#.#. .#. . . . # . .#. . . . . #  #.#"
			"#.#. # . . . . . . . . . . . . .# #.#"
			"#.#.#. . . . . . . . . . . . . . ##.#"
			"#.#. . . . . . . . . . . . . . . . .#"
			"#. .## * .## . .## . .## . .## . . .#"
			"#. . .## . .## . .## . .## . .## . .#"
			"#.#. . .## . .## . .## * .## . . . .#"
			"#.#.# . . . . . . . . . . . . . #.#.#"
			"#.#. #. . . . . . . . . . . . .# .#.#"
			"#.#. .#. . . . . . . . . . . .#. .#.#"
			"#.#. . . . . . . . . . . . . . . .#.#"
			"#.#. . .#. . . . . . . . . .#. . .#.#"
			"#.#. o . # . . . . . . . . # . o .#.#"
			"#.#. . . .#. . . . . . . .#. . . .#.#"
			"#.#################################.#"
			"#. . . . . . . . . . . . . . . . . X#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#.o. . .#. . .#. . . . . . . . . .o.#"
			"#.#####.#.###. .### ### ###.#######.#"
			"#. ####.#.###. .### ### ###.###### .#"
			"#. .###.#.###. .### ### ###.#####. .#"
			"#. . ##.#.###. .    ###    .#### . .#"
			"#. . .#.#.###. .### ### ###.###. . .#"
			"#. . . .#.###. .### ### ###.## . . .#"
			"#. . . . .###. .### ### ###.#. . . .#"
			"#. . . . . ##. .#  1   2  #.#. . . .#"
			"#. . . . . .#. .#  3 5 4  #.#. . . .#"
			"#. . . . . . .#.### ### ###. . . . .#"
			"#. ### . . .#. .### ### ###.#. . . .#"
			"#. ##. . . ##. .### ### ###.#. . . .#"
			"#. .o# . .###. .    ###    .#. . . .#"
			"## . # . ####. .### ### ###.##o. . .#"
			"###. # .#####. .### ### ###.###. . .#"
			"#### * ######. .### ### ###.#### . .#"
			"#############. . . . . . . .#####. .#"
			"#############. . . . . . . .###### .#"
			"#. . . . . . . .###########.#######.#"
			"#. ############. . . . . .#.#######.#"
			"#.*. . . . . . . ########. . . . .X.#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#......#.....#.....#.....#.....#....#"
			"#..###.o.###...###...###...###.o.####"
			"#.#####.#####.#####.#####.#####.#####"
			"#..###...###...###...###...###...####"
			"#...#.....#.....#.....#.....#.......#"
			"#.#...# #.#.# #.#.# #.#.# #.#.## ##.#"
			"#.#.*.#1#.#.#2#.#.#3#.#.#4#.#.# 5 #.#"
			"#.#...# #.#.# #.#.# #.#.# #.#.## ##.#"
			"#...#.....#.....#.....#.....#...*...#"
			"#..###...###...###...###...###...####"
			"#.#####.#####.#####.#####.#####.#####"
			"#..###...###...###...###...###...####"
			"#...#.....#.....#..X..#.....#.......#"
			"#.#...###.#.###.#.###.#.###.#.#####.#"
			"#.#.*.# #.#.# #.#.# #.#.# #.#.#   #.#"
			"#.#...###.#.###.#.###.#.###.#.#####.#"
			"#...#.....#.....#.....#.....#...*...#"
			"#..###...###...###...###...###...####"
			"#.#####.#####.#####.#####.#####.#####"
			"#..###.o.###...###...###...###.o.####"
			"#...#.....#.....#.....#.....#.......#"
			"#......#.....#.....#.....#.....#....#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#...##############1##############...#"
			"#.....############*############.....#"
			"#.......########## ##########.......#"
			"#.........######## ########.........#"
			"#...........###### ######...........#"
			"#.............#### ####.............#"
			"#...............## ##...............#"
			"#................o o................#"
			"#.################ ################.#"
			"#.################ ################.#"
			"#.################ ################.#"
			"#.#2 *                         * 3#.#"
			"#.################ ################.#"
			"#.################ ################.#"
			"#................o o................#"
			"#...............## ##...............#"
			"#.............#### ####.............#"
			"#...........###### ######...........#"
			"#.........######## ########.........#"
			"#.......########## ##########.......#"
			"#.....############*############.....#"
			"#.X.##############4##############...#"
			"#####################################"
	},
	{
    "-------------------------------------",

            "#####################################"
			"#.*. . .o.#. . . . .#. . . .o.#. .*.#"
			"#. . . . .#. . . . .#. . . . .#. . .#"
			"#### .###.#.#######.#.#####. .#.#####"
			"#### .###...#######...#####. ...#####"
			"#. . .#######################. . . .#"
			"#.###.#        1    2       #.#####.#"
			"#.# #.#                     #.#   #.#"
			"#.# #.            3          .#   #.#"
			"#.# #.#                     #.#   #.#"
			"#.# #.#        4    5       #.#   #.#"
			"#.###.#######################.#####.#"
			"#.*. . . . . . .###. . . . . . . .*.#"
			"#. . .###. . .###. . . .###. . . . .#"
			"#. . .#. . . .#. . . . . .#. . . ####"
			"#. . .#. . . .#. . .X. . .#. .#. ####"
			"#####.#.###. .#.###. .###.#. .#. ####"
			"#####. . . . . .#. . . .#.#. . .#####"
			"#########. . . .#. . . .#. . .#######"
			"#########. . . . . . . . . . .#######"
			"#. .o. . . .#####. . . .#### . .o. .#"
			"#.#########.#####. .#. .#### . . . .#"
			"#. . . . . .. . . . #. . . . . . . .#"
			"#####################################"
	},
  {
    "-------------------------------------",

    "#####################################"
    "#...................................#"
    "#..##....#..........................#"
    "#..#.#...#..........................#"
    "#..#..#..#.........*................#"
    "#..#...#.#..........................#"
    "#..#....##..........................#"
    "#..........#....#...................#"
    "#....o.....#....#...................#"
    "#..........#....#...................#"
    "#..........#....#............*......#"
    "#..........######...................#"
    "#..................######...........#"
    "#............o.....# 12 #...........#"
    "#..................#  3 #...........#"
    "#..................# 45 #...........#"
    "#..................######...........#"
    "#.........................##....#...#"
    "#....................o....#.#...#...#"
    "#.........................#..#..#...#"
    "#.........................#...#.#...#"
    "#..X......................#....##...#"
    "#...........................o.......#"
    "#####################################"
  },

  {
    ""
  }
};

LEVEL aLevelEdited[] = {
  { "", "" }
};
